(function (Drupal, $, once) {
  'use strict';
  Drupal.behaviors.elevatezoom = {
    attach: function (context, settings) {
      $(once('elevatezoom', '.elevatezoom', context)).each(function () {
        let shadow_color = $(this).data('shadow-color');
        let window_position = parseInt($(this).data('window-position'));
        let window_width = parseInt($(this).data('window-width'));
        let window_height = parseInt($(this).data('window-height'));
        let lens_size = parseInt($(this).data('lens-size'));
        let type = $(this).data('zoom-type');
        switch(type) {
          case 'basic_zoom':
            $(this).ezPlus({
              zoomWindowPosition: window_position,
              zoomWindowWidth: window_width,
              zoomWindowHeight: window_height,
              zoomWindowFadeIn: 500,
              zoomWindowFadeOut: 500,
              lensFadeIn: 500,
              lensFadeOut: 500,
              easing: true,
            });
            break;

          case 'tint_zoom':
            $(this).ezPlus({
              tint: true,
              tintColour: shadow_color,
              tintOpacity: 0.5,
              zoomWindowPosition: window_position,
              zoomWindowWidth: window_width,
              zoomWindowHeight: window_height,
              zoomWindowFadeIn: 500,
              zoomWindowFadeOut: 500,
              lensFadeIn: 500,
              lensFadeOut: 500,
              easing: true,
            });
            break;

          case 'mousewheel_zoom':
            $(this).ezPlus({
              tint: true,
              tintColour: shadow_color,
              tintOpacity: 0.5,
              zoomWindowPosition: window_position,
              zoomWindowWidth: window_width,
              zoomWindowHeight: window_height,
              scrollZoom: true,
              zoomWindowFadeIn: 500,
              zoomWindowFadeOut: 500,
              lensFadeIn: 500,
              lensFadeOut: 500,
              easing: true,
            });
            break;

          case 'lens_zoom':
            $(this).ezPlus({
              zoomType: 'lens',
              lensShape: 'round',
              lensSize: lens_size,
              lensFadeIn: 500,
              lensFadeOut: 500,
              easing: true,
            });
            break;

          case 'lightbox':
            $(this).ezPlus({
              zoomType: 'window',
              cursor: 'pointer',
              galleryActiveClass: "active",
              imageCrossfade: true,
              easing: true,
            });
            $(this).bind("click", function (e) {
              let ez = $(this).data('ezPlus');
              ez.closeAll();
              $.fancyboxPlus(ez.getGalleryList());
              return false;
            });
            break;

          // Galerry
          case 'mousewheel_zoom_gallery':
            $(this).ezPlus({
              gallery: 'elevate_zoom--mousewheel_zoom_gallery_list',
              cursor: 'pointer',
              galleryActiveClass: 'active',
              imageCrossfade: true,
              tint: true,
              tintColour: shadow_color,
              tintOpacity: 0.5,
              scrollZoom: true,
              zoomWindowPosition: window_position,
              zoomWindowWidth: window_width,
              zoomWindowHeight: window_height,
              zoomWindowFadeIn: 500,
              zoomWindowFadeOut: 500,
              lensFadeIn: 500,
              lensFadeOut: 500,
              easing: true,
            });
            break;

          case 'basic_zoom_gallery':
            $(this).ezPlus({
              gallery: 'elevate_zoom--basic_zoom_gallery_list',
              cursor: 'pointer',
              galleryActiveClass: 'active',
              imageCrossfade: true,
              zoomWindowPosition: window_position,
              zoomWindowWidth: window_width,
              zoomWindowHeight: window_height,
              zoomWindowFadeIn: 500,
              zoomWindowFadeOut: 500,
              lensFadeIn: 500,
              lensFadeOut: 500,
              easing: true,
            });
            break;

          case 'tint_zoom_gallery':
            $(this).ezPlus({
              gallery: 'elevate_zoom--tint_zoom_gallery_list',
              cursor: 'pointer',
              galleryActiveClass: 'active',
              tint: true,
              tintColour: shadow_color,
              tintOpacity: 0.5,
              zoomWindowPosition: window_position,
              zoomWindowWidth: window_width,
              zoomWindowHeight: window_height,
              zoomWindowFadeIn: 500,
              zoomWindowFadeOut: 500,
              lensFadeIn: 500,
              lensFadeOut: 500,
              easing: true,
            });
            break;

          case 'inner_zoom_gallery':
            $(this).ezPlus({
              gallery: 'elevate_zoom--inner_zoom_gallery_list',
              galleryActiveClass: 'active',
              zoomType: 'inner',
              cursor: 'crosshair',
              easing: true,
            });
            break;

          case 'lens_zoom_gallery':
            $(this).ezPlus({
              gallery: 'elevate_zoom--lens_zoom_gallery_list',
              cursor: 'pointer',
              galleryActiveClass: 'active',
              zoomType: 'lens',
              lensShape: 'round',
              lensSize: lens_size,
              easing: true,
            });
            break;

          case 'lightbox_gallery':
            $(this).ezPlus({
              gallery: 'elevate_zoom--lightbox_gallery_list',
              zoomType: 'lens',
              lensShape: 'round',
              cursor: 'pointer',
              galleryActiveClass: "active",
              imageCrossfade: true,
              easing: true,
            });

            $(this).bind("click", function (e) {
              let ez = $(this).data('ezPlus');
              ez.closeAll();
              $.fancyboxPlus(ez.getGalleryList());
              return false;
            });
            break;

          default:
            $(this).ezPlus({
              zoomType: 'inner',
              cursor: 'crosshair',
              easing: true,
            });
        }
        $('a img.img-thumbnail').on("click", function () {
          let caption = $(this).attr('title');
          let alt = $(this).attr('alt');
          let main = $(this).closest('.gallery-list').parent().find('.main-zoom');
          main.find('img').attr('alt',alt).attr('title',caption);
          main.find('figcaption').html(caption);
        });
      });
    }
  };

}(Drupal, jQuery, once));
